# Copyright 2022 The GPflow Contributors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""
Definitions of commonly used types.
"""
from typing import Any, Callable, Optional, Tuple, TypeVar

C = TypeVar("C", bound=Callable[..., Any])

Dimension = Optional[int]
"""
The size of a single observed dimension.

Use `None` if the size of that dimension is unknown.
"""

Shape = Optional[Tuple[Dimension, ...]]
"""
The complete shape of an observed object.

Use `None` if the object has a shape, but the shape is unknown.

Raise an exception if objects of that type can never have a shape.
"""
